from django.contrib.auth.models import User
from django.core.exceptions import ObjectDoesNotExist

from rest_framework import serializers

from fotos.models import Tag, Picture


class UserSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = User
        fields = ('url', 'username', 'password', 'email', 'first_name', 'last_name')


class TagSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = Tag
        fields = ('url', 'text')


class PictureSerializer(serializers.HyperlinkedModelSerializer):
    tags = TagSerializer(many=True,)

    class Meta:
        model = Picture
        fields = ('url', 'user', 'pub_date', 'longitude', 'latitude', 'image', 'tags', 'uuid')

    def create(self, validated_data):
        tags_data = validated_data.pop('tags', [])
        #print tags_data

        picture = Picture.objects.create(**validated_data)

        for tag in tags_data:
            try:
                t = Tag.objects.get(text=tag)
                picture.tags.add(t)
            except Tag.DoesNotExist:
                t = Tag.objects.create(text=tag)
                picture.tags.add(t)

        picture.save()
        return picture
